==> rk.ANOVA_0.01-6.tar.gz: rk.ANOVA/inst/rkward/plugins/Interactionplot.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!

function preprocess(){
	// add requirements etc. here
	echo("require(sciplot)\n");
}

function calculate(){
}

function printout(){
	// all the real work is moved to a custom defined function doPrintout() below
	// true in this case means: We want all the headers that should be printed in the output:
	doPrintout(true);
}

function preview(){
	preprocess();
	calculate();
	doPrintout(false);
}

function doPrintout(full){
	// read in variables from dialog
	var vrslFactrxxs = getValue("vrsl_Factrxxs");
	var vrslRspnsvct = getValue("vrsl_Rspnsvct");
	var vrslGrpngfct = getValue("vrsl_Grpngfct");
	var radPlottype = getValue("rad_Plottype");
	var chcStndrdrr = getValue("chc_Stndrdrr");
	var chcLegend = getValue("chc_Legend");
	var radElements = getValue("rad_Elements");
	var radBars = getValue("rad_Bars");
	var inpLegndlbl = getValue("inp_Legndlbl");

	// create the plot
	if(full) {
		echo("rk.header(\"Interaction plot\", level=1)\n");
	} else {}

	// in case there are generic plot options defined:

	var embGnrcpltpCodePrintout = getValue("emb_Gnrcpltp.code.printout");
	if(full) {
		echo("rk.graph.on()\n");
	} else {}
	if(radPlottype == "line") {
		echo("\ttry({\n\t\tlineplot.CI(");
	} else {
		echo("\ttry({\n\t\tbargraph.CI(");
	}
	if(vrslFactrxxs) {
		echo("\n\t\t\tx.factor=" + vrslFactrxxs);
	} else {}
	if(vrslRspnsvct) {
		echo(",\n\t\t\tresponse=" + vrslRspnsvct);
	} else {}
	if(vrslGrpngfct) {
		echo(",\n\t\t\tgroup=" + vrslGrpngfct);
	} else {}
	if(radPlottype == "line" & radElements != "b") {
		echo(",\n\t\t\ttype=\"" + radElements + "\"");
	} else {}
	if(radPlottype == "bar" & radBars == "split") {
		echo(",\n\t\t\tsplit=TRUE");
	} else {}
	if(radPlottype == "line" & !chcLegend & vrslGrpngfct != "") {
		echo(",\n\t\t\tlegend=FALSE");
	} else {}
	if(radPlottype == "bar" & chcLegend == "true" & vrslGrpngfct != "") {
		echo(",\n\t\t\tlegend=TRUE");
	} else {}
	if(chcLegend == "true" & vrslGrpngfct != "" & inpLegndlbl != "") {
		echo(",\n\t\t\ttrace.label=\"" + inpLegndlbl + "\"");
	} else {}
	if(!chcStndrdrr) {
		echo(",\n\t\t\tci.fun=function(x)c(mean(x, na.rm=TRUE), mean(x, na.rm=TRUE))");
	} else {}
	echo(embGnrcpltpCodePrintout);
	echo(")\n\t})\n");
	if(full) {
		echo("rk.graph.off()\n");
	} else {}
}

==> rk.ANOVA_0.01-10.tar.gz: rk.ANOVA/inst/rkward/plugins/Interactionplot.js <==
// this code was generated using the rkwarddev package.
//perhaps don't make changes here, but in the rkwarddev script instead!



function preprocess(){
	// add requirements etc. here
	echo("require(sciplot)\n");
}

function calculate(){
}

function printout(){
	// all the real work is moved to a custom defined function doPrintout() below
	// true in this case means: We want all the headers that should be printed in the output:
	doPrintout(true);
}

function preview(){
	preprocess();
	calculate();
	doPrintout(false);
}

function doPrintout(full){
	// read in variables from dialog
	var vrslFactrxxs = getValue("vrsl_Factrxxs");
	var vrslRspnsvct = getValue("vrsl_Rspnsvct");
	var vrslGrpngfct = getValue("vrsl_Grpngfct");
	var radPlottype = getValue("rad_Plottype");
	var chcStndrdrr = getValue("chc_Stndrdrr");
	var chcLegend = getValue("chc_Legend");
	var radElements = getValue("rad_Elements");
	var radBars = getValue("rad_Bars");
	var inpLegndlbl = getValue("inp_Legndlbl");

	// create the plot
	if(full) {
		echo("rk.header(\"Interaction plot\")\n");
	}

	// in case there are generic plot options defined:
	var embGnrcpltpCodePrintout = getValue("emb_Gnrcpltp.code.printout");
	if(full) {
		echo("rk.graph.on()\n");
	} else {}
	if(radPlottype == "line") {
		echo("\ttry({\n\t\tlineplot.CI(");
	} else {
		echo("\ttry({\n\t\tbargraph.CI(");
	}
	if(vrslFactrxxs) {
		echo("\n\t\t\tx.factor=" + vrslFactrxxs);
	} else {}
	if(vrslRspnsvct) {
		echo(",\n\t\t\tresponse=" + vrslRspnsvct);
	} else {}
	if(vrslGrpngfct) {
		echo(",\n\t\t\tgroup=" + vrslGrpngfct);
	} else {}
	if(radPlottype == "line" & radElements != "b") {
		echo(",\n\t\t\ttype=\"" + radElements + "\"");
	} else {}
	if(radPlottype == "bar" & radBars == "split") {
		echo(",\n\t\t\tsplit=TRUE");
	} else {}
	if(radPlottype == "line" & !chcLegend & vrslGrpngfct != "") {
		echo(",\n\t\t\tlegend=FALSE");
	} else {}
	if(radPlottype == "bar" & chcLegend == "true" & vrslGrpngfct != "") {
		echo(",\n\t\t\tlegend=TRUE");
	} else {}
	if(chcLegend == "true" & vrslGrpngfct != "" & inpLegndlbl != "") {
		echo(",\n\t\t\ttrace.label=\"" + inpLegndlbl + "\"");
	} else {}
	if(!chcStndrdrr) {
		echo(",\n\t\t\tci.fun=function(x)c(mean(x, na.rm=TRUE), mean(x, na.rm=TRUE))");
	} else {}
	echo(embGnrcpltpCodePrintout);
	echo(")\n\t})\n");
	if(full) {
		echo("rk.graph.off()\n");
	} else {}
}
